referencedBy property
The transitive closure of tables whose foreign keys reference this one, in their (unchanged) new-schema form. See ReferencedBy for why.
Implementation
final List<ReferencedBy> referencedBy;
The transitive closure of tables whose foreign keys reference this one, in their (unchanged) new-schema form. See ReferencedBy for why.
final List<ReferencedBy> referencedBy;