ForeignKeyInfo constructor
const
ForeignKeyInfo({})
Foreign key information for DDL generation.
This is a simple data class that holds the information needed to generate foreign key constraints in DDL statements.
Implementation
const ForeignKeyInfo({
required this.referencedTable,
required this.referencedColumn,
this.onDelete,
this.onUpdate,
});